==> haskell-genvalidity-property-1.0.0.0-193.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-645xvxm2GNLHlr7cIjF4HM
key:                  genvalidity-property-1.0.0.0-645xvxm2GNLHlr7cIjF4HM
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  a9c339f06445f3172386d22c33da5d60
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.6.6/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/genvalidity-property-1.0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-645xvxm2GNLHlr7cIjF4HM
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    genvalidity-1.1.1.0-1cygiBXmr98EcwwcYom5CO
    hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR
    validity-0.12.1.0-Lsdq3S1YVx6GOnXZaTodRl

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-property-1.0.0.0-194-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-DYICuTvr49Uhr14fYr8U1
key:                  genvalidity-property-1.0.0.0-DYICuTvr49Uhr14fYr8U1
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  ccc22fa1751c77a8ef74d3fd67f3e51e
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.6.6/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/genvalidity-property-1.0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-DYICuTvr49Uhr14fYr8U1
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    genvalidity-1.1.1.0-4ORseef1Qsj9tj2fPe8Pqa
    hspec-2.11.4-8QgnQwrEho14jh62SRkWei
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR
    validity-0.12.1.0-1ywEh9iJU1m6FQwCfRBtqj

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
